@@ -30,6 +30,8 @@ import matplotlib.pyplot as plt
 # from mpl_toolkits.axes_grid1.axes_divider import make_axes_locatable
 from mpl_toolkits.mplot3d import Axes3D
 import numpy as np
+import importlib_resources
+import pkg_resources
 
 
 def read_text(text_path):
@@ -51,7 +53,7 @@ class Lidar():
         
     def region(self):
         self.output_slider_variable = widgets.Text()
-        stream = resource_stream(__name__, 'data/filename.txt')
+        stream = pkg_resources.resource_stream(__name__, 'data/filename.txt')
        
         # Define function to bind value of the input to the output variable 
         def f(x):
